2020-12-22 Version: 1.0.10
- Release DetectRibFracture.

2020-12-03 Version: 1.0.9
- Update DetectLungNodule.

2020-10-23 Version: 1.0.8
- Update DetectLungNodule.

2020-10-23 Version: 1.0.7
- Update DetectLungNodule.

2020-10-13 Version: 1.0.6
- Release DetectSkinDisease.

2020-09-29 Version: 1.0.5
- Update CalcCACS.

2020-09-18 Version: 1.0.4
- Update DetectLungNodule, DetectSpineMRI, DetectKneeXRay, DetectCovid19Cad.

2020-09-09 Version: 1.0.3
- Release DetectKneeKeypointXRay, DetectHipKeypointXRay, CalcCACS, RunCTRegistration, ClassifyFNF.

